import { Status } from "../../DataFrame";
import { IntRange } from "../../Helpers";
import { IDevice } from "../Devices/IDevice";
import { ResponseResult } from "../FieldChangeResult";
import { ICustomUpdateActions } from "./CustomUpdateActions/ICustomUpdateActions";
import { IControllerUpdateInfo, IDeviceUpdateInfo } from "./IUpdateInfo";
export interface IUpdatesService {
    GetServiceName(): string;
    CheckControllerUpdateAsync(): Promise<IControllerUpdateInfo>;
    /**
     * Checks available device updates
     * @param deviceGuid
     */
    CheckDeviceUpdateAsync(deviceGuid: string): Promise<IDeviceUpdateInfo | ResponseResult<UpdateErrorCode>>;
    /**
     * Checks available device updates
     * @param device
     */
    CheckDeviceUpdateAsync(device: IDevice): Promise<IDeviceUpdateInfo | ResponseResult<UpdateErrorCode>>;
    InstallControllerUpdatesAsync<T extends ICustomUpdateActions>(updateProgress: UpdateProgress, updateAction?: UpdateAction<T>): Promise<Status.OK | ResponseResult<UpdateErrorCode>>;
    /**
     * Installs a device update if available
     * @param device IDevice object
     * @param updateProgress callback function which is called when recived information about update progress from controller
     * @param updateAction custom actions to do (may be protocol-dependent or may not occur)
     * @returns Status.OK when request is finished (regardless of UpdateProgress result, the update result is given in the callback)
     */
    InstallDeviceUpdateAsync<T extends ICustomUpdateActions>(device: IDevice, updateProgress: UpdateProgress, updateAction?: UpdateAction<T>): Promise<Status.OK | ResponseResult<UpdateErrorCode>>;
    /**
     * Installs a device update if available
     * @param deviceGuid device Guid
     * @param updateProgress callback function which is called when recived information about update progress from controller
     * @param updateAction custom actions to do (may be protocol-dependent or may not occur)
     * @returns Status.OK when request is finished (regardless of UpdateProgress result, the update result is given in the callback)
     */
    InstallDeviceUpdateAsync<T extends ICustomUpdateActions>(deviceGuid: string, updateProgress: UpdateProgress, updateAction?: UpdateAction<T>): Promise<Status.OK | ResponseResult<UpdateErrorCode>>;
    CheckControllerVersionAsync(): Promise<string | ResponseResult<UpdateErrorCode>>;
    /**
     * Function returns current software version.
     * @param deviceGuid
     */
    CheckDeviceVersionAsync(deviceGuid: string): Promise<string | ResponseResult<UpdateErrorCode>>;
    /**
     * Function returns current software version.
     * @param device
     */
    CheckDeviceVersionAsync(device: IDevice): Promise<string | ResponseResult<UpdateErrorCode>>;
}
export declare type UpdateProgress = (updateProgress: UpdateProgressInfo) => void;
export declare type UpdateAction<T extends ICustomUpdateActions> = (updateAction: T) => any;
export declare type Progress = IntRange<0, 101>;
export declare enum UpdateStatus {
    DownloadingFailure = -5,
    InstallationStopped = -4,
    InstallationError = -3,
    IncompatiblePackage = -2,
    Error = -1,
    OK = 0,
    DownloadingPackage = 1,
    CheckingPackage = 2,
    PreparingForUpgrade = 3,
    Upgrading = 4,
    MovingData = 5,
    Reloading = 6,
    Upgraded = 7
}
export declare class UpdateProgressInfo {
    Percentage: Progress;
    Status: UpdateStatus;
    UpdateInfo: number;
}
export declare enum UpdateErrorCode {
    DeviceIsUpToDate = 0,
    CannotFindDevice = 1,
    UnsupportedApiVersion = 2,
    UnsupportedDevice = 3,
    CannotGetFirmwareVersion = 4,
    CannotGetUpdates = 5,
    CannotProcessUpdate = 6,
    UpdateActionsNotSupported = 7
}
