var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Api } from "../../Api";
import { Status } from "../../DataFrame";
import { ControllerExtensionsService } from "../Controller/ControllerExtensionsService";
import { DevicesService } from "../Devices/DevicesService";
import { ResponseResult } from "../FieldChangeResult";
import { DeviceUpdateProvider } from "./DeviceUpdateProvider";
import { UpdateErrorCode } from "./IUpdatesService";
export class UpdatesService {
    constructor() {
        this._updateProviderService = Api.Get(DeviceUpdateProvider.ServiceName);
    }
    GetServiceName() {
        return UpdatesService.ServiceName;
    }
    CheckDeviceVersionAsync(dev) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let device;
            if (typeof dev == 'string') {
                const result = yield Api.Get(DevicesService.ServiceName).GetDevice(dev);
                if (result != null)
                    device = result;
                else
                    return new ResponseResult(UpdateErrorCode.CannotFindDevice, `Device with specified GUID ${dev} does not exists.`);
            }
            else {
                device = dev;
            }
            if (device.ProtocolGuid == null)
                return new ResponseResult(UpdateErrorCode.UnsupportedDevice, `Device does not contains data about protocol GUID.`);
            const softwareInfo = yield ((_a = (yield this._updateProviderService.GetUpdateProvidersAsync(device.ProtocolGuid)).first()) === null || _a === void 0 ? void 0 : _a.GetSoftwareVersionAsync(device));
            if (softwareInfo.Type != null)
                return softwareInfo;
            return softwareInfo;
        });
    }
    CheckDeviceUpdateAsync(dev) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let device;
            if (typeof dev == 'string') {
                const result = yield Api.Get(DevicesService.ServiceName).GetDevice(dev);
                if (result != null)
                    device = result;
                else
                    return new ResponseResult(UpdateErrorCode.CannotFindDevice, `Device with specified GUID ${dev} does not exists.`);
            }
            else {
                device = dev;
            }
            if (device.ProtocolGuid == null)
                return new ResponseResult(UpdateErrorCode.UnsupportedDevice, `Device does not contains data about protocol GUID.`);
            const updateInfo = yield ((_a = (yield this._updateProviderService.GetUpdateProvidersAsync(device.ProtocolGuid)).first()) === null || _a === void 0 ? void 0 : _a.GetAvailableUpdateAsync(device));
            if (updateInfo.Type != null)
                return updateInfo;
            const result = new Update();
            result.CurrentResourceVersion = updateInfo.CurrentResourceVersion;
            result.NewResourceVersion = updateInfo.Update.Version;
            result.UpdatedResourceName = updateInfo.UpdatedResourceName;
            result.UpdateResourceGuid = updateInfo.Update.ResourceGuid;
            result.Protocol = yield (yield Api.Get(ControllerExtensionsService.ServiceName).GetProtocolInfoAsync(device.ProtocolGuid)).first().Name;
            result.ProtocolGuid = device.ProtocolGuid;
            return result;
        });
    }
    InstallDeviceUpdateAsync(dev, updateProgress, updateAction) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let device;
            if (typeof dev == 'string') {
                const result = yield Api.Get(DevicesService.ServiceName).GetDevice(dev);
                if (result != null)
                    device = result;
                else
                    return new ResponseResult(UpdateErrorCode.CannotFindDevice, `Device with specified GUID ${dev} does not exists.`);
            }
            else {
                device = dev;
            }
            if (device.ProtocolGuid == null)
                return new ResponseResult(UpdateErrorCode.UnsupportedDevice, `Device does not contains data about protocol GUID.`);
            const updateInfo = yield ((_a = (yield this._updateProviderService.GetUpdateProvidersAsync(device.ProtocolGuid)).first()) === null || _a === void 0 ? void 0 : _a.GetAvailableUpdateAsync(device));
            if (updateInfo.Type != null)
                return updateInfo;
            const updateInstallResult = yield (yield this._updateProviderService.GetUpdateProvidersAsync(device.ProtocolGuid)).first().InstallUpdateAsync(updateInfo, updateProgress, updateAction);
            if (updateInstallResult.Type != null)
                return updateInstallResult;
            return Status.OK;
        });
    }
    CheckControllerUpdateAsync() {
        throw new Error("Method not implemented.");
    }
    CheckControllerVersionAsync() {
        throw new Error("Method not implemented.");
    }
    InstallControllerUpdatesAsync(updateProgress, updateAction) {
        throw new Error("Method not implemented.");
    }
}
UpdatesService.ServiceName = "UpdatesService";
class Update {
    constructor() {
        this._updatedResourceName = "";
        this._updateResourceGuid = "";
        this._protocol = "";
        this._protocolGuid = "";
        this._currentResourceVersion = "";
        this._newResourceVersion = "";
    }
    get UpdatedResourceName() {
        return this._updatedResourceName;
    }
    get UpdateResourceGuid() {
        return this._updateResourceGuid;
    }
    get Protocol() {
        return this._protocol;
    }
    get ProtocolGuid() {
        return this._protocolGuid;
    }
    get CurrentResourceVersion() {
        return this._currentResourceVersion;
    }
    get NewResourceVersion() {
        return this._newResourceVersion;
    }
    set UpdatedResourceName(value) {
        this._updatedResourceName = value;
    }
    set UpdateResourceGuid(value) {
        this._updateResourceGuid = value;
    }
    set Protocol(value) {
        this._protocol = value;
    }
    set ProtocolGuid(value) {
        this._protocolGuid = value;
    }
    set CurrentResourceVersion(value) {
        this._currentResourceVersion = value;
    }
    set NewResourceVersion(value) {
        this._newResourceVersion = value;
    }
}
//# sourceMappingURL=UpdatesService.js.map